#include <Wire.h>     // Include the Wire library for I2C communication
#include <SD.h>       // Include the SD library for SD card
#include <TMRpcm.h>   // Include the TMRpcm library for audio playback
#include <RTClib.h>   // Include the RTClib library for RTC

#define SD_CS_PIN   4    // Pin connected to the CS of SD card module
#define RTC_SDA_PIN A4   // Pin connected to SDA of RTC module
#define RTC_SCL_PIN A5   // Pin connected to SCL of RTC module
#define AUDIO_OUT_PIN 9  // Pin connected to audio jack
#define BUZZER_PIN 10    // Pin connected to the buzzer

RTC_DS3231 rtc;         // Create an instance of RTC_DS3231
TMRpcm tmrpcm;          // Create an instance of TMRpcm

void setup() 
{
  
  Serial.begin(9600);   // Initialize serial communication
  Serial.println("start");
  // Initialize SD card
  if (!SD.begin(SD_CS_PIN)) 
  {
    Serial.println("SD Card initialization failed!");
    return;
  }

  // Initialize RTC
  Wire.begin();         // Initialize I2C
  if (!rtc.begin()) {
    Serial.println("RTC initialization failed!");
    return;
  }
  
  // Set the RTC time (YY, MM, DD, HH, MM, SS)
 rtc.adjust(DateTime(2024, 3, 03, 10,07 , 0)); // Set the time to 2024-02-15 09:30:00
  
  // Initialize TMRpcm
  tmrpcm.speakerPin = AUDIO_OUT_PIN;
  tmrpcm.setVolume(5);  // Set volume (0 to 7)

  // Initialize buzzer pin
  pinMode(BUZZER_PIN, OUTPUT);
}

void loop() {
  DateTime now = rtc.now();  // Get current time from RTC
  
  // Display current time on serial console
  Serial.print("Current Time: ");
  Serial.print(now.year());
  Serial.print("-");
  Serial.print(now.month());
  Serial.print("-");
  Serial.print(now.day());
  Serial.print(" ");
  Serial.print(now.hour());
  Serial.print(":");
  Serial.print(now.minute());
  Serial.print(":");
  Serial.println(now.second());
  digitalWrite(BUZZER_PIN, LOW);
  
  // Check if it's 9.30 o'clock
  if (now.hour() == 9 && now.minute() == 35 && now.second() == 0) 
  {
    playAudio();  // Play audio file
    Serial.println("Time matched");
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    
  }
  else if (now.hour() == 10 && now.minute() == 45 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 11 && now.minute() == 45 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 12 && now.minute() == 30 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 13 && now.minute() == 30 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 14 && now.minute() == 30 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(20000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 15 && now.minute() == 30 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(30000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else if (now.hour() == 16 && now.minute() == 30 && now.second() == 0) {
    digitalWrite(BUZZER_PIN, HIGH); // Turn on the buzzer
    Serial.println("Buzzer on");
    delay(30000); // Buzzer duration (30 seconds)
    digitalWrite(BUZZER_PIN, LOW); // Turn off the buzzer
    Serial.println("Time matched");
  }
  else {
    Serial.println("out of time");
    }
  delay(1000); // Add a delay to prevent busy-waiting and reduce CPU usage
}

void playAudio() {
  // Check if audio file exists
  if (SD.exists("audio.wav")) {
    tmrpcm.play("audio.wav");  // Play audio file
    delay(65000); // Adjust the delay according to the duration of the audio file
  } else {
    Serial.println("Audio file not found!");
  }
}
